A Django app to download, extract and load campaign finance and lobbying activity data from the California Secretary of State's [CAL-ACCESS](http://www.sos.ca.gov/prd/cal-access/) database

-  Documentation: [django-calaccess.californiacivicdata.org](https://django-calaccess.californiacivicdata.org/en/latest/)
-  Issues: [github.com/california-civic-data-coalition/django-calaccess-raw-data/issues](https://github.com/california-civic-data-coalition/django-calaccess-raw-data/issues)
-  Packaging: [pypi.python.org/pypi/django-calaccess-raw-data](https://pypi.python.org/pypi/django-calaccess-raw-data)
-  Testing: [github.com/california-civic-data-coalition/django-calaccess-raw-data/actions/](https://github.com/california-civic-data-coalition/django-calaccess-raw-data/actions/workflows/tests.yaml)
